@@ -4,8 +4,8 @@ use strict;
 use Text::Xslate;
 
 my $tx  = Text::Xslate->new(
-    cache  => 0,
-    module => ['URI::Escape'],
+    module    => ['URI::Escape'],
+    cache_dir => '.eg_cache',
 );
 
 print $tx->render_string(<<'T', { app_param => "foo & bar" });
